import requests
import json

class Mandrill(object):
    app = None
    mandrill_api = None
    api_key = None

    def __init__(self, app=None):
        if app:
            self.init_app(app)

    def init_app(self, app):
        self.api_key = app.config['MANDRILL_API_KEY']
        self.app = app

    def send_email(self, **kwargs):
        """
        Sends an email using Mandrill's API. Returns a
        Requests :class:`Response` object.

        At a minimum kwargs must contain the keys to, from_email, and text.

        Everything passed as kwargs except for the keywords 'key', 'async',
        and 'ip_pool' will be sent as key-value pairs in the message object.

        Reference https://mandrillapp.com/api/docs/messages.JSON.html#method=send
        for all the available options.
        """
        if not self.api_key:
            raise ValueError('No Mandrill API key has been configured')
        data = {
            'async': kwargs.pop('async', False),
            'ip_pool': kwargs.pop('ip_pool', ''),
            'key': kwargs.pop('key', self.api_key),
            'message': kwargs,
        }
        data['message'].setdefault('from_email',
                                  self.app.config['MANDRILL_DEFAULT_FROM'])
        response = requests.post(self.messages_endpoint,
                                 data=json.dumps(data),
                                 headers={'Content-Type':'application/json'})
        response.raise_for_status()
        return response

    @property
    def messages_endpoint(self):
        return 'https://mandrillapp.com/api/1.0/messages/send.json'



"""
Flask-Mandrill
==============

A Flask Extension to remove some of the boiler plate encountered when
sending emails with `Mandrill <http://www.mandrill.com/>`_

Installation
````````````

.. code:: bash

    $ pip install flask-mandrill


Usage
`````

.. code:: python

        from flask import Flask
        from from flask.ext.mandrill import Mandrill

        app = Flask(__name__)
        app.config['MANDRILL_API_KEY'] = 'your api key'
        mandrill = Mandrill(app)
        mandrill.send_email(
            from_email='someone@yourdomain.com',
            to=[{'email': 'someoneelse@someotherdomain.com'}],
            text='Hello World'
        )
"""

from setuptools import setup


setup(
    name='Flask-Mandrill',
    version='0.1.1',
    url='http://github.com/volker48/flask-mandrill',
    license='MIT',
    author='Marcus McCurdy',
    author_email='marcus.mccurdy@gmail.com',
    description='Adds Mandrill support to Flask applications',
    long_description=__doc__ + '\n\n' +
                     open('HISTORY.rst').read(),
    py_modules=['flask_mandrill'],
    zip_safe=False,
    platforms='any',
    install_requires=[
        'Flask',
        'requests'
        ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
        ]
)
